# This file was generated by a script, please do not edit it by hand.
# See `$ rake generate_constants` and data/generate_constants.rb for more info.

module Unicode
  module Emoji
    REGEX_PROP_COMPONENT = /[\#\*0-9‍⃣️🇦-🇿🏻-🏿🦰-🦳󠀠-󠁿]/
  end
end
